package com.yanzhu.system.api;

import com.yanzhu.system.api.domain.SysUserUniopen;
import com.yanzhu.system.api.domain.vo.WxMaLoginBody;
import com.yanzhu.system.api.model.LoginUser;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;
import com.yanzhu.common.core.constant.SecurityConstants;
import com.yanzhu.common.core.constant.ServiceNameConstants;
import com.yanzhu.common.core.domain.R;
import com.yanzhu.system.api.domain.SysUser;
import com.yanzhu.system.api.factory.RemoteUserFallbackFactory;

import java.util.List;
import java.util.Map;

/**
 * 用户服务
 * 
 * @author ruoyi
 */
@FeignClient(contextId = "remoteUserService", value = ServiceNameConstants.SYSTEM_SERVICE, fallbackFactory = RemoteUserFallbackFactory.class)
public interface RemoteUserService
{
    /**
     * 获取小程序授权
     * @param code 授权码
     * @param source 请求来源
     * @return
     */
    @GetMapping("/sysUserUniopen/getMaOpenId/{code}")
    public R<Map<String,Object>> getMaOpenId(@PathVariable("code") String code, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 获取小程序手机号
     * @param body 加密参数
     * @param source 请求来源
     * @return
     */
    @PostMapping("/sysUserUniopen/getMaPhoneNumber")
    public R<Map<String,Object>> getMaPhoneNumber(@RequestBody WxMaLoginBody body, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 查询小程序授权
     * @param maOpenId 小程序授权id
     * @param source 请求来源
     * @return
     */
    @GetMapping("/sysUserUniopen/findByMaOpenId/{maOpenId}")
    public R<SysUserUniopen> findByMaOpenId(@PathVariable("maOpenId") String maOpenId, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 新增小程序唯一授权
     *
     * @param sysUserUniopen 小程序授权信息
     * @param source 请求来源
     * @return 结果
     */
    @PostMapping("/sysUserUniopen/add")
    public R<Integer> addSysUserUniopen(@RequestBody SysUserUniopen sysUserUniopen, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 修改小程序唯一授权
     *
     * @param sysUserUniopen 小程序授权信息
     * @param source 请求来源
     * @return 结果
     */
    @PutMapping("/sysUserUniopen/edit")
    public R<Integer> editSysUserUniopen(@RequestBody SysUserUniopen sysUserUniopen, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 通过用户名查询用户信息
     *
     * @param username 用户名
     * @param source 请求来源
     * @return 结果
     */
    @GetMapping("/user/info/{username}")
    public R<LoginUser> getUserInfo(@PathVariable("username") String username, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 通过用户名查询用户信息
     *
     * @param username 用户名
     * @param deptId 公司主键
     * @param source 请求来源
     * @return 结果
     */
    @GetMapping("/user/infoAndDept/{username}/{deptId}")
    public R<LoginUser> getUserInfo(@PathVariable("username") String username,@PathVariable("deptId") Long deptId, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 通过用户主键查询用户信息
     *
     * @param userId 用户主键
     * @param source 请求来源
     * @return 结果
     */
    @GetMapping("/user/sysUser/{userId}")
    public R<SysUser> getSysUserInfo(@PathVariable("userId") Long userId, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 注册用户信息
     *
     * @param sysUser 用户信息
     * @param source 请求来源
     * @return 结果
     */
    @PostMapping("/user/register")
    public R<Long> registerUserInfo(@RequestBody SysUser sysUser, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    @PutMapping("/user")
    public R<Long> updateUserInfo(@RequestBody SysUser sysUser, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);
}
